@@ -816,7 +816,7 @@ write_json_proto_node_list(GSList *proto_node_list_head, write_json_data *pdata)
         // We assume all values of a json key have roughly the same layout. Thus we can use the first value to derive
         // attributes of all the values.
         gboolean has_value = value_string_repr != NULL;
-        gboolean is_pseudo_text_field = fi->hfinfo->id == 0;
+        gboolean is_pseudo_text_field = fi->hfinfo->id == hf_text_only;
 
         wmem_free(NULL, value_string_repr); // fvalue_to_string_repr returns allocated buffer
 
@@ -2428,14 +2428,6 @@ static void format_field_values(output_fields_t* fields, gpointer field_index, g
         break;
     case 'a':
         /* print the value of all accurrences of the field */
-        if (g_ptr_array_len(fv_p) != 0) {
-            /*
-             * This isn't the first occurrence. so add the "aggregator"
-             * character as a separator between the previous element
-             * and this element.
-             */
-            g_ptr_array_add(fv_p, (gpointer)ws_strdup_printf("%c", fields->aggregator));
-        }
         break;
     default:
         ws_assert_not_reached();
@@ -2553,6 +2545,9 @@ static void write_specified_fields(fields_format format, output_fields_t *fields
 
                 /* Output the array of (partial) field values */
                 for (j = 0; j < g_ptr_array_len(fv_p); j++ ) {
+                    if (j != 0) {
+                        fputc(fields->aggregator, fh);
+                    }
                     str = (gchar *)g_ptr_array_index(fv_p, j);
                     print_escaped_csv(fh, str);
                     g_free(str);
@@ -2576,7 +2571,7 @@ static void write_specified_fields(fields_format format, output_fields_t *fields
                 fv_p = fields->field_values[i];
 
                 /* Output the array of (partial) field values */
-                for (j = 0; j < (g_ptr_array_len(fv_p)); j+=2 ) {
+                for (j = 0; j < (g_ptr_array_len(fv_p)); j++ ) {
                     str = (gchar *)g_ptr_array_index(fv_p, j);
 
                     fprintf(fh, "  <field name=\"%s\" value=", field);
@@ -2605,7 +2600,7 @@ static void write_specified_fields(fields_format format, output_fields_t *fields
                 json_dumper_begin_array(dumper);
 
                 /* Output the array of (partial) field values */
-                for (j = 0; j < (g_ptr_array_len(fv_p)); j += 2) {
+                for (j = 0; j < (g_ptr_array_len(fv_p)); j++ ) {
                     str = (gchar *) g_ptr_array_index(fv_p, j);
                     json_dumper_value_string(dumper, str);
                     g_free(str);
@@ -2633,7 +2628,7 @@ static void write_specified_fields(fields_format format, output_fields_t *fields
                 json_dumper_begin_array(dumper);
 
                 /* Output the array of (partial) field values */
-                for (j = 0; j < (g_ptr_array_len(fv_p)); j += 2) {
+                for (j = 0; j < (g_ptr_array_len(fv_p)); j++ ) {
                     str = (gchar *)g_ptr_array_index(fv_p, j);
                     json_dumper_value_string(dumper, str);
                     g_free(str);
